==> tencentcloud-sdk-nodejs-3.0.32.tgz: package/tencentcloud/tmt/v20180321/tmt_client.js <==
/*
 * Copyright (c) 2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const models = require("./models");
const AbstractClient = require('../../common/abstract_client')
const ImageTranslateResponse = models.ImageTranslateResponse;
const SpeechTranslateResponse = models.SpeechTranslateResponse;
const ImageRecord = models.ImageRecord;
const LanguageDetectRequest = models.LanguageDetectRequest;
const LanguageDetectResponse = models.LanguageDetectResponse;
const ItemValue = models.ItemValue;
const TextTranslateResponse = models.TextTranslateResponse;
const SpeechTranslateRequest = models.SpeechTranslateRequest;
const ImageTranslateRequest = models.ImageTranslateRequest;
const TextTranslateRequest = models.TextTranslateRequest;


/**
 * tmt client
 * @class
 */
class TmtClient extends AbstractClient {

    constructor(credential, region, profile) {
        super("tmt.tencentcloudapi.com", "2018-03-21", credential, region, profile);
    }
    
    /**
     * 提供中文到英文、英文到中文的等多种语言的文本内容翻译服务， 经过大数据语料库、多种解码算法、翻译引擎深度优化，在新闻文章、生活口语等不同语言场景中都有深厚积累，翻译结果专业评价处于行业顶级水平。

     * @param {TextTranslateRequest} req
     * @param {function(string, TextTranslateResponse):void} cb
     * @public
     */
    TextTranslate(req, cb) {
        let resp = new TextTranslateResponse();
        this.request("TextTranslate", req, resp, options, cb);
    }

    /**
     * 提供中文到英文、英文到中文两种语言的图片翻译服务，可自动识别图片中的文本内容并翻译成目标语言，识别后的文本按行翻译，后续会提供可按段落翻译的版本
     * @param {ImageTranslateRequest} req
     * @param {function(string, ImageTranslateResponse):void} cb
     * @public
     */
    ImageTranslate(req, cb) {
        let resp = new ImageTranslateResponse();
        this.request("ImageTranslate", req, resp, options, cb);
    }

    /**
     * 本接口提供音频内文字识别 + 翻译功能，目前开放中到英的语音翻译服务。
待识别和翻译的音频文件可以是 pcm、mp3、amr和speex 格式，音频内语音清晰，采用流式传输和翻译的方式。

     * @param {SpeechTranslateRequest} req
     * @param {function(string, SpeechTranslateResponse):void} cb
     * @public
     */
    SpeechTranslate(req, cb) {
        let resp = new SpeechTranslateResponse();
        this.request("SpeechTranslate", req, resp, options, cb);
    }

    /**
     * 可自动识别文本内容的语言种类，轻量高效，无需额外实现判断方式，使面向客户的服务体验更佳。 
     * @param {LanguageDetectRequest} req
     * @param {function(string, LanguageDetectResponse):void} cb
     * @public
     */
    LanguageDetect(req, cb) {
        let resp = new LanguageDetectResponse();
        this.request("LanguageDetect", req, resp, options, cb);
    }


}
module.exports = TmtClient;

==> tencentcloud-sdk-nodejs-3.0.36.tgz: package/tencentcloud/tmt/v20180321/tmt_client.js <==
/*
 * Copyright (c) 2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const models = require("./models");
const AbstractClient = require('../../common/abstract_client')
const ImageTranslateResponse = models.ImageTranslateResponse;
const SpeechTranslateResponse = models.SpeechTranslateResponse;
const ImageRecord = models.ImageRecord;
const LanguageDetectRequest = models.LanguageDetectRequest;
const LanguageDetectResponse = models.LanguageDetectResponse;
const ItemValue = models.ItemValue;
const TextTranslateResponse = models.TextTranslateResponse;
const SpeechTranslateRequest = models.SpeechTranslateRequest;
const ImageTranslateRequest = models.ImageTranslateRequest;
const TextTranslateRequest = models.TextTranslateRequest;


/**
 * tmt client
 * @class
 */
class TmtClient extends AbstractClient {

    constructor(credential, region, profile) {
        super("tmt.tencentcloudapi.com", "2018-03-21", credential, region, profile);
    }
    
    /**
     * 提供中文到英文、英文到中文的等多种语言的文本内容翻译服务， 经过大数据语料库、多种解码算法、翻译引擎深度优化，在新闻文章、生活口语等不同语言场景中都有深厚积累，翻译结果专业评价处于行业顶级水平。

     * @param {TextTranslateRequest} req
     * @param {function(string, TextTranslateResponse):void} cb
     * @public
     */
    TextTranslate(req, cb) {
        let resp = new TextTranslateResponse();
        this.request("TextTranslate", req, resp, cb);
    }

    /**
     * 提供中文到英文、英文到中文两种语言的图片翻译服务，可自动识别图片中的文本内容并翻译成目标语言，识别后的文本按行翻译，后续会提供可按段落翻译的版本
     * @param {ImageTranslateRequest} req
     * @param {function(string, ImageTranslateResponse):void} cb
     * @public
     */
    ImageTranslate(req, cb) {
        let resp = new ImageTranslateResponse();
        this.request("ImageTranslate", req, resp, cb);
    }

    /**
     * 本接口提供音频内文字识别 + 翻译功能，目前开放中到英的语音翻译服务。
待识别和翻译的音频文件可以是 pcm、mp3、amr和speex 格式，音频内语音清晰，采用流式传输和翻译的方式。

     * @param {SpeechTranslateRequest} req
     * @param {function(string, SpeechTranslateResponse):void} cb
     * @public
     */
    SpeechTranslate(req, cb) {
        let resp = new SpeechTranslateResponse();
        this.request("SpeechTranslate", req, resp, cb);
    }

    /**
     * 可自动识别文本内容的语言种类，轻量高效，无需额外实现判断方式，使面向客户的服务体验更佳。 
     * @param {LanguageDetectRequest} req
     * @param {function(string, LanguageDetectResponse):void} cb
     * @public
     */
    LanguageDetect(req, cb) {
        let resp = new LanguageDetectResponse();
        this.request("LanguageDetect", req, resp, cb);
    }


}
module.exports = TmtClient;
